@@ -1,4 +1,7 @@
 package EWS::Client;
+BEGIN {
+  $EWS::Client::VERSION = '1.141040';
+}
 BEGIN {
   $EWS::Client::VERSION = '1.130570';
 }
@@ -8,10 +11,14 @@ with qw/
     EWS::Client::Role::SOAP
     EWS::Client::Role::GetItem
     EWS::Client::Role::FindItem
+    EWS::Client::Role::FindFolder
+    EWS::Client::Role::GetFolder
 /;
 use EWS::Client::Contacts;
 use EWS::Client::Calendar;
+use EWS::Client::Folder;
 use URI::Escape ();
+use Log::Report;
 
 has username => (
     is => 'rw',
@@ -53,6 +60,18 @@ sub _build_calendar {
     return EWS::Client::Calendar->new({ client => $self });
 }
 
+has folders => (
+    is => 'ro',
+    isa => 'EWS::Client::Folder',
+    lazy_build => 1,
+);
+
+sub _build_folders {
+    my $self = shift;
+    return EWS::Client::Folder->new({ client => $self });
+}
+
+
 sub BUILDARGS {
     my ($class, @rest) = @_;
     my $params = (scalar @rest == 1 ? $rest[0] : {@rest});
@@ -100,7 +119,7 @@ EWS::Client - Microsoft Exchange Web Services Client
 
 =head1 VERSION
 
-version 1.130570
+version 1.141040
 
 =head1 SYNOPSIS
 
@@ -207,6 +226,12 @@ Retrieves the L<EWS::Client::Contacts> object which allows retrieval of
 contact entries and their telephone numbers. See that linked manual page for
 more details.
 
+=head2 $ews->folders()
+
+Retrieves the L<EWS::Client::Folder> object which allows retrieval of
+mailbox folder entries and their sizes. See that linked manual page for
+more details.
+
 =head1 KNOWN ISSUES
 
 =over 4
@@ -228,7 +253,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by University of Oxford.
+This software is copyright (c) 2014 by University of Oxford.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
